@@ -20,11 +20,11 @@ ACTION_NAMES = {
     "k" : "k", "kick" : "k",  "meleekick" : "k",
     "o" : "o", "overheadslam" : "o",  "overhead" : "o", "over" : "o", "oh" : "o",  "meleeoverhead" : "o",  "slam" : "o",
     "t" : "t", "tracer" : "t",  "webtracer" : "t",  "cluster" : "t",  "webcluster" : "t",
-    "s" : "s", "swing" : "s", "webswing" : "s",  "highswing" : "s",  "lowswing" : "s", "z" : "s", "zip" : "s", "webzip" : "s",
-    "a" : "a", "automatic swing" : "a", "autoswing" : "a", "automatic" : "a", "auto" : "a", "easyswing" : "a", "easy" : "a", "simple swing" : "a", "simple" : "a",
+    "s" : "s", "swing" : "s", "webswing" : "s",  "highswing" : "s",  "lowswing" : "s", "z" : "s", "zip" : "s", "webzip" : "s", "ms" : "s", "manualswing" : "s", "manual" : "s",
+    "a" : "a", "automatic swing" : "a", "autoswing" : "a", "automatic" : "a", "auto" : "a", "easyswing" : "a", "easy" : "a", "simple swing" : "a", "simple" : "a", "as" : "a",
     "w" : "w", "whiff" : "w", "webwhiff" : "w", "swingwhiff" : "w", "wiff" : "w", "web wiff" : "w", "swing wiff" : "w",
     "g" : "g", "getoverhere" : "g", "goh" : "g", "webpull" : "g", "pull" : "g",
-    "G" : "G", "getoverheretargeting" : "G", "getoverheretargetting" : "G", "goht" : "G",
+    "G" : "G", "getoverheretargeting" : "G", "getoverheretargetting" : "G", "goht" : "G", "goh.t" : "G",
     "u" : "u", "uppercut" : "u", "upper" : "u", "amazingcombo" : "u",
     "b" : "b", "burn" : "b", "burntracer" : "b", "burncluster" : "b", "fire" : "b", "firetracer" : "b", "firecluster" : "b", "flame" : "b", "flametracer" : "b", "flamecluster" : "b",
     "+" : "+", "/" : "+",
@@ -549,9 +549,9 @@ def loadMoveStacks():
     kickReverseTriggerCancelTimes = ACTIONS["t"].cancelTimes.copy()
     overheadReverseTriggerCancelTimes = ACTIONS["t"].cancelTimes.copy()
     for action in punchReverseTriggerCancelTimes:
-        punchReverseTriggerCancelTimes[action] += ACTIONS["p"].damageTime - 1 - ACTIONS["t"].damageTime
-        kickReverseTriggerCancelTimes[action] += ACTIONS["k"].damageTime - 1 - ACTIONS["t"].damageTime
-        overheadReverseTriggerCancelTimes[action] += ACTIONS["o"].damageTime - 1 - ACTIONS["t"].damageTime
+        punchReverseTriggerCancelTimes[action] += ACTIONS["p"].cancelTimes["t"] - 1
+        kickReverseTriggerCancelTimes[action] += ACTIONS["k"].cancelTimes["t"]  - 1
+        overheadReverseTriggerCancelTimes[action] += ACTIONS["o"].cancelTimes["t"]  - 1
 
     ACTIONS["p+t"] = Action (
         name = "Punch Reverse Trigger",
@@ -562,10 +562,10 @@ def loadMoveStacks():
         firstDamageTime = ACTIONS["p"].damageTime - 1,
         cancelTimes = punchReverseTriggerCancelTimes,
         chargeActivations = {
-            "t" : ACTIONS["p"].damageTime - 1  - ACTIONS["t"].damageTime + ACTIONS["t"].chargeActivations["t"]
+            "t" : ACTIONS["p"].cancelTimes["t"] - 1 + ACTIONS["t"].chargeActivations["t"]
         },
         awaitCharges = { 
-            "t" :  ACTIONS["p"].damageTime - 1 - ACTIONS["t"].damageTime
+            "t" :  ACTIONS["p"].cancelTimes["t"] - 1
         }
     )
 
@@ -578,10 +578,10 @@ def loadMoveStacks():
         firstDamageTime = ACTIONS["k"].damageTime - 1,
         cancelTimes = kickReverseTriggerCancelTimes,
         chargeActivations = {
-            "t" : ACTIONS["k"].damageTime - 1  - ACTIONS["t"].damageTime + ACTIONS["t"].chargeActivations["t"]
+            "t" : ACTIONS["k"].cancelTimes["t"] - 1 + ACTIONS["t"].chargeActivations["t"]
         },
         awaitCharges = { 
-            "t" :  ACTIONS["k"].damageTime - 1 - ACTIONS["t"].damageTime
+            "t" :  ACTIONS["k"].cancelTimes["t"] - 1
         }
     )
 
@@ -590,14 +590,14 @@ def loadMoveStacks():
         damage = ACTIONS["o"].damage + ACTIONS["t"].damage,
         procsTracer = True,
         procTime = 0,
-        damageTime = ACTIONS["o"].damageTime,
+        damageTime = ACTIONS["o"].damageTime - 1,
         firstDamageTime = ACTIONS["o"].damageTime - 1,
         cancelTimes = overheadReverseTriggerCancelTimes,
         chargeActivations = {
-            "t" : ACTIONS["o"].damageTime - 1  - ACTIONS["t"].damageTime + ACTIONS["t"].chargeActivations["t"]
+            "t" : ACTIONS["o"].cancelTimes["t"] - 1 + ACTIONS["t"].chargeActivations["t"]
         },
         awaitCharges = { 
-            "t" :  ACTIONS["o"].damageTime - 1 - ACTIONS["t"].damageTime
+            "t" : ACTIONS["o"].cancelTimes["t"] - 1
         }
     )
 
